@@ -1,59 +1,59 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    Username,
-    NodeLabel,
-    Output,
-    InstanceTypeStatus,
-    ID,
-    RegionID,
-    Endpoint,
-    Usage,
-    RecordID,
-    IngressHost,
-    Command,
-    BandWidth,
-    TimeInterval,
-    Type,
-    SecurityGroupID,
-    InstanceName,
-    Number,
-    Status,
-    Path,
-    Time,
-    DNSType,
-    Key,
-    Value,
-    InstanceType,
-    NodeType,
-    Weight,
-    DomainName,
-    Port,
-    ZoneID,
-    DNSLine,
-    Hostname,
-    GPUType,
-    NodeName,
-    ImageID,
     InstanceTypeStatusCategory,
-    Name,
+    TimeInterval,
     ServiceType,
-    KeyType,
-    NodeStatus,
+    Status,
     InternetPayType,
-    Version,
-    Bool,
-    Password,
-    Size,
-    IP,
-    Info,
-    InstanceID,
-    Price,
+    DomainName,
+    Path,
+    Key,
     Subdomain,
+    NodeStatus,
+    Version,
+    Hostname,
+    Output,
+    Password,
+    RecordID,
+    Command,
+    ZoneID,
+    GPUType,
+    Usage,
+    NodeLabel,
+    DNSLine,
+    BandWidth,
+    Weight,
+    Endpoint,
+    IngressHost,
+    NodeName,
+    Name,
+    ImageID,
+    Number,
+    Size,
+    InstanceType,
+    DateTime,
+    IP,
+    Port,
+    Value,
+    ID,
+    InstanceID,
+    DNSType,
+    Username,
+    KeyType,
+    InstanceName,
+    SecurityGroupID,
+    InstanceTypeStatus,
+    RegionID,
+    Bool,
     Data,
+    Price,
+    Type,
+    Time,
+    NodeType,
     Token,
-    PayType,
-    DateTime
+    Info,
+    PayType
 )
 
 class Condition(Entity):
@@ -411,6 +411,7 @@ class NodeMeta(ExpiredEntity):
         run_time: Time,
         k3s_version: Version,
         label: NodeLabel,
+        private_ip: IP,
         _life_time: Number = Number(5)
     ):
         self.name=name
@@ -418,6 +419,7 @@ class NodeMeta(ExpiredEntity):
         self.run_time=run_time
         self.k3s_version=k3s_version
         self.label=label
+        self.private_ip=private_ip
         self._life_time=_life_time
         super().__init__(_life_time)
 
@@ -578,7 +580,6 @@ class Ingress(ExpiredEntity):
         self.namespace=namespace
         self._life_time=_life_time
         super().__init__(_life_time)
-
     @property
     def hosts(self):
         return [IngressHost(h) for h in self.host_info.get_value().split(',')]
