@@ -43,22 +43,22 @@ class K3SRepository(Repository):
     def create_config_maps(self, cluster_name: Name, config_map_user_settings: List[ConfigMapUserSetting])->None:
         raise NotImplementedError
 
-    def create_namespace(self, cluster_name: Name, namespace_name: Name)->None:
+    def create_namespace(self, cluster_name: Name, namespace_name: Name)->bool:
         raise NotImplementedError
 
     def create_node(self, condition: Condition, node_user_setting: NodeUserSetting)->Optional[NodeInfo]:
         raise NotImplementedError
 
-    def create_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->None:
+    def create_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->bool:
         raise NotImplementedError
 
-    def create_secrets(self, cluster_name: Name, secret_user_settings: List[SecretUserSetting])->None:
+    def create_secrets(self, cluster_name: Name, secret_user_settings: List[SecretUserSetting])->bool:
         raise NotImplementedError
 
-    def delete_nodes(self, node_infos: List[NodeInfo])->None:
+    def delete_nodes(self, node_infos: List[NodeInfo])->bool:
         raise NotImplementedError
 
-    def delete_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->None:
+    def delete_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->bool:
         raise NotImplementedError
 
     def get_config_maps(self, cluster_name: Name, namespace_name: Name)->Optional[List[ConfigMap]]:
@@ -85,7 +85,7 @@ class K3SRepository(Repository):
     def get_secrets(self, cluster_name: Name, namespace_name: Name)->Optional[List[Secret]]:
         raise NotImplementedError
 
-    def upload_to_oss_from_pod(self, pod_oss_operation_info: PodOSSOperationInfo)->None:
+    def upload_to_oss_from_pod(self, pod_oss_operation_info: PodOSSOperationInfo)->bool:
         raise NotImplementedError
 
     def get_ingresses(self, cluster_name: Name, namespace_name: Name)->Optional[List[Ingress]]:
